Index: /main/trunk/greenstone2/perllib/plugins/CSVPlugin.pm
===================================================================
--- /main/trunk/greenstone2/perllib/plugins/CSVPlugin.pm	(revision 36480)
+++ /main/trunk/greenstone2/perllib/plugins/CSVPlugin.pm	(revision 36481)
@@ -25,5 +25,5 @@
 ###########################################################################
 
-package NewCSVPlugin;
+package CSVPlugin;
 
 use extrametautil;
@@ -40,5 +40,5 @@
 
 sub BEGIN {
-    @NewCSVPlugin::ISA = ('MetadataRead', 'ReadTextFile', 'CSVFieldSeparator');
+    @CSVPlugin::ISA = ('MetadataRead', 'ReadTextFile', 'CSVFieldSeparator');
     binmode(STDERR, ":utf8");
 
@@ -61,5 +61,5 @@
 
 
-my $options = { 'name'     => "NewCSVPlugin",
+my $options = { 'name'     => "CSVPlugin",
 		'desc'     => "{CSVPlugin.desc}",
 		'abstract' => "no",
@@ -133,6 +133,6 @@
     return undef unless $self->can_process_this_file_for_metadata($filename_full_path);
     
-    print STDERR "\n<Processing n='$file' p='NewCSVPlugin'>\n" if ($gli);
-    print STDERR "NewCSVPlugin: processing $file\n" if ($self->{'verbosity'}) > 1;
+    print STDERR "\n<Processing n='$file' p='CSVPlugin'>\n" if ($gli);
+    print STDERR "CSVPlugin: processing $file\n" if ($self->{'verbosity'}) > 1;
 
     my $outhandle = $self->{'outhandle'};
@@ -145,5 +145,5 @@
     my ($language, $content_encoding) = $self->textcat_get_language_encoding ($filename_full_path);
     if ($self->{'verbosity'} > 2) {
-	print $outhandle "NewCSVPlugin: reading $file as ($content_encoding,$language)\n";
+	print $outhandle "CSVPlugin: reading $file as ($content_encoding,$language)\n";
     }
     # store these values for read
@@ -391,6 +391,6 @@
     my ($outhandle, $failhandle, $gli, $file, $error) = @_;
 
-    print $outhandle "NewCSVPlugin Error: $file: $error\n";
-    print $failhandle "NewCSVPlugin Error: $file: $error\n";
+    print $outhandle "CSVPlugin Error: $file: $error\n";
+    print $failhandle "CSVPlugin Error: $file: $error\n";
     print STDERR "<ProcessingError n='$file' r='$error'/>\n" if ($gli);
 }
Index: /main/trunk/greenstone2/perllib/strings.properties
===================================================================
--- /main/trunk/greenstone2/perllib/strings.properties	(revision 36480)
+++ /main/trunk/greenstone2/perllib/strings.properties	(revision 36481)
@@ -882,5 +882,7 @@
 CSVFieldSeparator.metadata_value_separator: The character you've consistently used to separate multiple metadata values for a single metadata field within a cell of the csv spreadsheet. If you used the vertical bar as the separator character, then set metadata_value_separator to \| (backslash vertical bar).
 
-CSVPlugin.desc:A plugin for files in comma-separated value format. A new document will be created for each line of the file.
+CSVPlugin.desc:A plugin for files in comma-separated value format. Metadata can be assigned to source documents (specified in the Filename field), or new documents created for each line of the file.
+
+CSVDeprecatedPlugin.desc:An old plugin for files in comma-separated value format. A new document will be created for each line of the file.
 
 DateExtractor.desc:Helper extractor plugin for extracting historical date information from text.
@@ -1140,5 +1142,5 @@
 MediaWikiPlugin.remove_title_suffix_exp:A Perl regular expression to trim the extracted title. For example, \\s-(.+) will trim title contents after "-".
 
-MetadataCSVPlugin.desc:A plugin for metadata in comma-separated value format. The Filename field in the CSV file is used to determine which document the metadata belongs to.
+MetadataCSVDeprecatedPlugin.desc:An old plugin for metadata in comma-separated value format. The Filename field in the CSV file is used to determine which document the metadata belongs to.
 
 MetadataPass.desc:On-the-side base class to BaseImporter that supports metadata plugins utilise metadata_read pass of import.pl

Index: /main/trunk/greenstone2/perllib/plugins/CSVDeprecatedPlugin.pm
===================================================================
--- /main/trunk/greenstone2/perllib/plugins/CSVDeprecatedPlugin.pm	(revision 36480)
+++ /main/trunk/greenstone2/perllib/plugins/CSVDeprecatedPlugin.pm	(revision 36481)
@@ -1,5 +1,5 @@
 ###########################################################################
 #
 # CSVPlugin.pm -- A plugin for files in comma-separated value format
 #
 # A component of the Greenstone digital library software
@@ -25,5 +25,5 @@
 ###########################################################################
 
-package CSVPlugin;
+package CSVDeprecatedPlugin;
 
 use SplitTextFile;
@@ -36,7 +36,7 @@
 use Text::CSV;
 
 # CSVPlugin is a sub-class of SplitTextFile.
 sub BEGIN {
-    @CSVPlugin::ISA = ('MetadataRead', 'SplitTextFile', 'CSVFieldSeparator');
+    @CSVDeprecatedPlugin::ISA = ('MetadataRead', 'SplitTextFile', 'CSVFieldSeparator');
 }
 
@@ -58,6 +58,6 @@
 
 
-my $options = { 'name'     => "CSVPlugin",
-		'desc'     => "{CSVPlugin.desc}",
+my $options = { 'name'     => "CSVDeprecatedPlugin",
+		'desc'     => "{CSVDeprecatedPlugin.desc}",
 		'abstract' => "no",
 		'inherits' => "yes",
@@ -1,5 +1,5 @@
 ###########################################################################
 #
-# CSVPlugin.pm -- A plugin for files in comma-separated value format
+# CSVDeprecatedPlugin.pm -- A plugin for files in comma-separated value format
 #
 # A component of the Greenstone digital library software
@@ -36,7 +36,7 @@
 use Text::CSV;
 
-# CSVPlugin is a sub-class of SplitTextFile.
+# CSVDeprecatedPlugin is a sub-class of SplitTextFile.
 sub BEGIN {
Index: /main/trunk/greenstone2/perllib/plugins/MetadataCSVDeprecatedPlugin.pm
===================================================================
--- /main/trunk/greenstone2/perllib/plugins/MetadataCSVDeprecatedPlugin.pm	(revision 36480)
+++ /main/trunk/greenstone2/perllib/plugins/MetadataCSVDeprecatedPlugin.pm	(revision 36481)
@@ -1,5 +1,5 @@
 ###########################################################################
 #
 # MetadataCSVPlugin.pm -- A plugin for metadata in comma-separated value format
 #
 # A component of the Greenstone digital library software
@@ -25,5 +25,5 @@
 ###########################################################################
 
-package MetadataCSVPlugin;
+package MetadataCSVDeprecatedPlugin;
 
 
@@ -43,5 +43,5 @@
 # methods with identical signatures take precedence in the order given in the ISA list.
 sub BEGIN {
-    @MetadataCSVPlugin::ISA = ('MetadataRead', 'BaseImporter', 'CSVFieldSeparator');
+    @MetadataCSVDeprecatedPlugin::ISA = ('MetadataRead', 'BaseImporter', 'CSVFieldSeparator');
 }
 
@@ -58,6 +58,6 @@
 
 
-my $options = { 'name'     => "MetadataCSVPlugin",
-		'desc'     => "{MetadataCSVPlugin.desc}",
+my $options = { 'name'     => "MetadataCSVDeprecatedPlugin",
+		'desc'     => "{MetadataCSVDeprecatedPlugin.desc}",
 		'abstract' => "no",
 		'inherits' => "yes",
@@ -115,6 +115,6 @@
     return undef unless $self->can_process_this_file_for_metadata($filename_full_path);
     
-    print STDERR "\n<Processing n='$file' p='MetadataCSVPlugin'>\n" if ($gli);
-    print STDERR "MetadataCSVPlugin: processing $file\n" if ($self->{'verbosity'}) > 1;
+    print STDERR "\n<Processing n='$file' p='MetadataCSVDeprecatedPlugin'>\n" if ($gli);
+    print STDERR "MetadataCSVDeprecatedPlugin: processing $file\n" if ($self->{'verbosity'}) > 1;
 
     my $outhandle = $self->{'outhandle'};
@@ -129,8 +129,8 @@
     open(CSV_FILE, "$filename_full_path");
     my $csv_file_reader = new multiread();
-    $csv_file_reader->set_handle('MetadataCSVPlugin::CSV_FILE');
+    $csv_file_reader->set_handle('MetadataCSVDeprecatedPlugin::CSV_FILE');
     $csv_file_reader->read_file(\$csv_file_content);
 
     # Would be nice if MetadataCSVPlugin was extended to support a minus
     # option to choose the character encoding the CSV file is in 
     # For now we will assume it is always in UTF8
@@ -280,6 +280,6 @@
     my ($outhandle, $failhandle, $gli, $file, $error) = @_;
 
-    print $outhandle "MetadataCSVPlugin Error: $file: $error\n";
-    print $failhandle "MetadataCSVPlugin Error: $file: $error\n";
+    print $outhandle "MetadataCSVDeprecatedPlugin Error: $file: $error\n";
+    print $failhandle "MetadataCSVDeprecatedPlugin Error: $file: $error\n";
     print STDERR "<ProcessingError n='$file' r='$error'/>\n" if ($gli);
 }
@@ -1,5 +1,5 @@
 ###########################################################################
 #
-# MetadataCSVPlugin.pm -- A plugin for metadata in comma-separated value format
+# MetadataCSVDeprecatedPlugin.pm -- A plugin for metadata in comma-separated value format
 #
 # A component of the Greenstone digital library software
@@ -129,8 +129,8 @@
     $csv_file_reader->read_file(\$csv_file_content);
 
-    # Would be nice if MetadataCSVPlugin was extended to support a minus
+    # Would be nice if MetadataCSVDeprecatedPlugin was extended to support a minus
     # option to choose the character encoding the CSV file is in 
     # For now we will assume it is always in UTF8